package com.shixing.sxedit;

/**
 * 音频管理器
 *
 * */
public class SXAudioManager {

    private long mNativeAudioManager;

    public SXAudioManager(long nativeAudioManager) {
        mNativeAudioManager = nativeAudioManager;
    }
    /**
     * 设置音频的时长，如不设置则取maxTrackOutPoint()的值
     *
     * @param duration 时长，单位为秒
     */
    public void setDuration(double duration) {
        nSetDuration(mNativeAudioManager, duration);
    }
    /**
     * 获取音轨时长
     *
     * @return 单位为秒
     */
    public double getDuration() {
        return nDuration(mNativeAudioManager);
    }
    /**
     * 获取音轨中音频结束时间点最大的时间
     *
     * @return 单位为秒
     */
    public double getMaxTrackOutPoint() {
        return nMaxTrackOutPoint(mNativeAudioManager);
    }
    /**
     * 当前时间跳到time对应的时间
     *
     * @param time 单位为秒
     */
    public void seek(double time) {
        nSeek(mNativeAudioManager, time);
    }
    /**
     * 获取当前的播放时间
     * @return 单位为秒
     */
    public double getCurrentTime() {
        return nCurrentTime(mNativeAudioManager);
    }
    /**
     * 获取音轨输出音频的采样率
     * @return 采样率
     */
    public double getOutputSampleRate() {
        return nOutputSampleRate(mNativeAudioManager);
    }
    /**
     * 获取音轨输出音频的声道数
     * @note 默认双声道
     * @return 声道数
     */
    public double getOutputChannelCount() {
        return nOutputChannelCount(mNativeAudioManager);
    }

    native static void nSetDuration(long nativeManager, double duration);
    native static double nDuration(long nativeManager);
    native static double nMaxTrackOutPoint(long nativeManager);
    native static void nSeek(long nativeManager, double time);
    native static double nCurrentTime(long nativeManager);
    native static double nOutputSampleRate(long nativeManager);
    native static double nOutputChannelCount(long nativeManager);
    native static void nStop(long nativeManager);
}
